#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-BxZDSrZUbecCKRkcr8aJRn
key:                  aeson-warning-parser-0.1.1-BxZDSrZUbecCKRkcr8aJRn
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  e2229bd96155fe5f7e4c3e6af360c610
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-BxZDSrZUbecCKRkcr8aJRn
depends:
    aeson-2.2.1.0-ISVQ3jiqbQ6Is6pNVe1jQU base-4.18.2.1 containers-0.6.7
    generic-deriving-1.14.7-8XM7Blsx62c69TFabhctGB
    rio-0.1.24.0-LqOwi9oNo1aF9P5V9IHXGO
    rio-prettyprint-0.1.8.0-FGRO8MiEofW5TuZoro9Yez text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-9qQGbgjzyj0ISlxTMt28N2

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

